@@ -1,4 +1,4 @@
-__version__ = "0.1.15"
+__version__ = "0.1.17"
 
 import warnings
 from getpass import getpass
@@ -19,6 +19,17 @@ Please enter OPENAI API KEY:""")
 except ImportError:
     warnings.warn("IPython could not be imported, are you in Google Colab?")
 
+def init():
+    try:
+        from .ipython_traceback import init_exception_hook
+        init_exception_hook()
+    except ImportError:
+        warnings.warn("IPython could not be imported, are you in Google Colab?")
+
+
 def deactivate():
     IPython.get_ipython().set_custom_exc((Exception,),
-                                     None)
\ No newline at end of file
+                                     None)
+
+def change_model(model="code-davinci-002"):
+    os.environ["OPENAI_MODEL"] = model
\ No newline at end of file
