@@ -2,6 +2,7 @@ import requests
 import os
 import json
 from getpass import getpass
+import warnings
 
 def predict_prompt(prompt):
   apiKey = os.environ.get("OPENAI_API_KEY")
@@ -13,7 +14,7 @@ Please enter OPENAI API KEY:""")
     apiKey = apiKey.strip()
     assert "sk-" in apiKey, "API Key needs to start with sk-..."
     os.environ["OPENAI_API_KEY"] = apiKey
-  model = 'text-davinci-003'
+  model = os.get("OPENAI_MODEL",'text-davinci-003')
   temperature = 0.
   maxTokens = 150
 
@@ -34,5 +35,4 @@ Please enter OPENAI API KEY:""")
   try:
     return response_json['choices'][0]['text']
   except KeyError:
-    print(response_json)
-    raise KeyError
\ No newline at end of file
+    warnings.warn(response_json)
\ No newline at end of file
